from ..exceptions import *
from .. import globals


class ServerResponse:

    def __init__(self, dict, client, debug):
        self._client = client
        self._debug = debug
        if dict is None:
            raise MissingDataInResultException
        else:
            self.buildFromDictionary(dict)

    def buildFromDictionary(self, dict):
        if dict is None:
            raise MissingDataInResultException
        self.httpStatusCode = dict["httpStatusCode"]
        self.errorMessage = dict["errorMessage"]

    @staticmethod
    def getQueryString(tabs=1, subobjectsRemaining=4):
        tabStr = globals.getTabStr(tabs)

        return f""" {{
{tabStr}httpStatusCode
{tabStr}errorMessage
{tabStr[0:-4]}}} """
